import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface OneDashboardConfig extends cdktf.TerraformMetaArguments {
    /**
     * The New Relic account ID where you want to create the dashboard.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The dashboard's description.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#description OneDashboard#description}
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * The dashboard's name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#name OneDashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Determines who can see or edit the dashboard. Valid values are private, public_read_only, public_read_write. Defaults to public_read_only.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#permissions OneDashboard#permissions}
     *
     * @stability stable
     */
    readonly permissions?: string;
    /**
     * page block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#page OneDashboard#page}
     *
     * @stability stable
     */
    readonly page: OneDashboardPage[];
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetAreaNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetArea {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetAreaNrqlQuery[];
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetBarNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetBar {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Use this item to filter the current dashboard.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#filter_current_dashboard OneDashboard#filter_current_dashboard}
     *
     * @stability stable
     */
    readonly filterCurrentDashboard?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Related entities. Currently only supports Dashboard entities, but may allow other cases in the future.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#linked_entity_guids OneDashboard#linked_entity_guids}
     *
     * @stability stable
     */
    readonly linkedEntityGuids?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetBarNrqlQuery[];
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetBillboardNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetBillboard {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * The critical threshold value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#critical OneDashboard#critical}
     *
     * @stability stable
     */
    readonly critical?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * The warning threshold value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#warning OneDashboard#warning}
     *
     * @stability stable
     */
    readonly warning?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetBillboardNrqlQuery[];
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetBulletNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetBullet {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * The maximum value for the visualization.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#limit OneDashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetBulletNrqlQuery[];
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetFunnelNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetFunnel {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetFunnelNrqlQuery[];
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetHeatmapNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetHeatmap {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetHeatmapNrqlQuery[];
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetHistogramNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetHistogram {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetHistogramNrqlQuery[];
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetJsonNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetJson {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetJsonNrqlQuery[];
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetLineNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetLine {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetLineNrqlQuery[];
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetMarkdown {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#text OneDashboard#text}.
     *
     * @stability stable
     */
    readonly text?: string;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetPieNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetPie {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Use this item to filter the current dashboard.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#filter_current_dashboard OneDashboard#filter_current_dashboard}
     *
     * @stability stable
     */
    readonly filterCurrentDashboard?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Related entities. Currently only supports Dashboard entities, but may allow other cases in the future.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#linked_entity_guids OneDashboard#linked_entity_guids}
     *
     * @stability stable
     */
    readonly linkedEntityGuids?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetPieNrqlQuery[];
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetStackedBarNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetStackedBar {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetStackedBarNrqlQuery[];
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetTableNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetTable {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Use this item to filter the current dashboard.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#filter_current_dashboard OneDashboard#filter_current_dashboard}
     *
     * @stability stable
     */
    readonly filterCurrentDashboard?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Related entities. Currently only supports Dashboard entities, but may allow other cases in the future.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#linked_entity_guids OneDashboard#linked_entity_guids}
     *
     * @stability stable
     */
    readonly linkedEntityGuids?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetTableNrqlQuery[];
}
/**
 * @stability stable
 */
export interface OneDashboardPage {
    /**
     * The dashboard page's description.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#description OneDashboard#description}
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * The dashboard page's name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#name OneDashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * widget_area block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#widget_area OneDashboard#widget_area}
     *
     * @stability stable
     */
    readonly widgetArea?: OneDashboardPageWidgetArea[];
    /**
     * widget_bar block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#widget_bar OneDashboard#widget_bar}
     *
     * @stability stable
     */
    readonly widgetBar?: OneDashboardPageWidgetBar[];
    /**
     * widget_billboard block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#widget_billboard OneDashboard#widget_billboard}
     *
     * @stability stable
     */
    readonly widgetBillboard?: OneDashboardPageWidgetBillboard[];
    /**
     * widget_bullet block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#widget_bullet OneDashboard#widget_bullet}
     *
     * @stability stable
     */
    readonly widgetBullet?: OneDashboardPageWidgetBullet[];
    /**
     * widget_funnel block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#widget_funnel OneDashboard#widget_funnel}
     *
     * @stability stable
     */
    readonly widgetFunnel?: OneDashboardPageWidgetFunnel[];
    /**
     * widget_heatmap block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#widget_heatmap OneDashboard#widget_heatmap}
     *
     * @stability stable
     */
    readonly widgetHeatmap?: OneDashboardPageWidgetHeatmap[];
    /**
     * widget_histogram block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#widget_histogram OneDashboard#widget_histogram}
     *
     * @stability stable
     */
    readonly widgetHistogram?: OneDashboardPageWidgetHistogram[];
    /**
     * widget_json block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#widget_json OneDashboard#widget_json}
     *
     * @stability stable
     */
    readonly widgetJson?: OneDashboardPageWidgetJson[];
    /**
     * widget_line block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#widget_line OneDashboard#widget_line}
     *
     * @stability stable
     */
    readonly widgetLine?: OneDashboardPageWidgetLine[];
    /**
     * widget_markdown block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#widget_markdown OneDashboard#widget_markdown}
     *
     * @stability stable
     */
    readonly widgetMarkdown?: OneDashboardPageWidgetMarkdown[];
    /**
     * widget_pie block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#widget_pie OneDashboard#widget_pie}
     *
     * @stability stable
     */
    readonly widgetPie?: OneDashboardPageWidgetPie[];
    /**
     * widget_stacked_bar block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#widget_stacked_bar OneDashboard#widget_stacked_bar}
     *
     * @stability stable
     */
    readonly widgetStackedBar?: OneDashboardPageWidgetStackedBar[];
    /**
     * widget_table block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html#widget_table OneDashboard#widget_table}
     *
     * @stability stable
     */
    readonly widgetTable?: OneDashboardPageWidgetTable[];
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html newrelic_one_dashboard}.
 *
 * @stability stable
 */
export declare class OneDashboard extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard.html newrelic_one_dashboard} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: OneDashboardConfig);
    private _accountId?;
    /**
     * @stability stable
     */
    get accountId(): number | undefined;
    /**
     * @stability stable
     */
    set accountId(value: number | undefined);
    /**
     * @stability stable
     */
    resetAccountId(): void;
    /**
     * @stability stable
     */
    get accountIdInput(): number | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string | undefined;
    /**
     * @stability stable
     */
    set description(value: string | undefined);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get guid(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    get permalink(): string;
    private _permissions?;
    /**
     * @stability stable
     */
    get permissions(): string | undefined;
    /**
     * @stability stable
     */
    set permissions(value: string | undefined);
    /**
     * @stability stable
     */
    resetPermissions(): void;
    /**
     * @stability stable
     */
    get permissionsInput(): string | undefined;
    private _page?;
    /**
     * @stability stable
     */
    get page(): OneDashboardPage[];
    /**
     * @stability stable
     */
    set page(value: OneDashboardPage[]);
    /**
     * @stability stable
     */
    get pageInput(): OneDashboardPage[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
